import { DiffFile } from "@git-diff-view/core";
import { ref } from "reactivity-store";
import { DiffModeEnum } from "./DiffViewContext";
import type { highlighter } from "@git-diff-view/core";
import type { CSSProperties, ForwardedRef, ReactNode } from "react";
export declare enum SplitSide {
    old = 1,
    new = 2
}
export type DiffViewProps<T> = {
    data?: {
        oldFile?: {
            fileName?: string | null;
            fileLang?: string | null;
            content?: string | null;
        };
        newFile?: {
            fileName?: string | null;
            fileLang?: string | null;
            content?: string | null;
        };
        hunks: string[];
    };
    extendData?: {
        oldFile?: Record<string, {
            data: T;
        }>;
        newFile?: Record<string, {
            data: T;
        }>;
    };
    diffFile?: DiffFile;
    className?: string;
    style?: CSSProperties;
    /**
     * provide a custom highlighter
     * eg: lowlight, refractor, starry-night, shiki
     */
    registerHighlighter?: typeof highlighter;
    diffViewMode?: DiffModeEnum;
    diffViewWrap?: boolean;
    diffViewFontSize?: number;
    diffViewHighlight?: boolean;
    diffViewAddWidget?: boolean;
    renderWidgetLine?: ({ diffFile, side, lineNumber, onClose, }: {
        lineNumber: number;
        side: SplitSide;
        diffFile: DiffFile;
        onClose: () => void;
    }) => ReactNode;
    renderExtendLine?: ({ diffFile, side, data, lineNumber, onUpdate, }: {
        lineNumber: number;
        side: SplitSide;
        data: T;
        diffFile: DiffFile;
        onUpdate: () => void;
    }) => ReactNode;
    onAddWidgetClick?: (lineNumber: number, side: SplitSide) => void;
};
export declare const DiffView: (<T>(props: DiffViewProps<T> & {
    ref?: ForwardedRef<{
        getDiffFileInstance: () => DiffFile;
    }>;
}) => ReactNode) & {
    displayName?: string;
};
export declare const version: string;
//# sourceMappingURL=DiffView.d.ts.map